==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/pages/table-view/EditTableViewContextProvider.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/pages/table-view/EditTableViewContextProvider.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../utils/client.es', './EditTableViewContext.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _client = require("../../utils/client.es");

  var _EditTableViewContext = _interopRequireWildcard(require("./EditTableViewContext.es"));

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = (0, _reactRouterDom.withRouter)(function (_ref) {
    var children = _ref.children,
        _ref$match$params = _ref.match.params,
        dataDefinitionId = _ref$match$params.dataDefinitionId,
        dataListViewId = _ref$match$params.dataListViewId;

    var _useReducer = (0, _react.useReducer)(_EditTableViewContext.reducer, _EditTableViewContext.initialState),
        _useReducer2 = _slicedToArray(_useReducer, 2),
        state = _useReducer2[0],
        dispatch = _useReducer2[1];

    (0, _react.useEffect)(function () {
      (0, _client.getItem)("/o/data-engine/v2.0/data-definitions/data-definition-fields/field-types").then(function (fieldTypes) {
        dispatch({
          payload: {
            fieldTypes: fieldTypes
          },
          type: _EditTableViewContext.UPDATE_FIELD_TYPES
        });
      });
    }, []);
    (0, _react.useEffect)(function () {
      (0, _client.getItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinitionId)).then(function (dataDefinition) {
        dispatch({
          payload: {
            dataDefinition: dataDefinition
          },
          type: _EditTableViewContext.UPDATE_DATA_DEFINITION
        });
      });
    }, [dataDefinitionId]);
    (0, _react.useEffect)(function () {
      if (dataListViewId) {
        (0, _client.getItem)("/o/data-engine/v2.0/data-list-views/".concat(dataListViewId)).then(function (dataListView) {
          dispatch({
            payload: {
              dataListView: dataListView
            },
            type: _EditTableViewContext.UPDATE_DATA_LIST_VIEW
          });
        });
      }
    }, [dataListViewId]);
    return _react["default"].createElement(_EditTableViewContext["default"].Provider, {
      value: [state, dispatch]
    }, children);
  });

  exports["default"] = _default;
  //# sourceMappingURL=EditTableViewContextProvider.es.js.map
});
//# sourceMappingURL=EditTableViewContextProvider.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/pages/table-view/EditTableViewContextProvider.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/pages/table-view/EditTableViewContextProvider.es", ['module', 'exports', 'require', 'frontend-js-react-web$react', 'app-builder-web$react-router-dom', '../../utils/client.es', './EditTableViewContext.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _client = require("../../utils/client.es");

  var _EditTableViewContext = _interopRequireWildcard(require("./EditTableViewContext.es"));

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function _slicedToArray(arr, i) {
    return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
  }

  function _nonIterableRest() {
    throw new TypeError("Invalid attempt to destructure non-iterable instance");
  }

  function _iterableToArrayLimit(arr, i) {
    if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
      return;
    }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
      for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
        _arr.push(_s.value);if (i && _arr.length === i) break;
      }
    } catch (err) {
      _d = true;_e = err;
    } finally {
      try {
        if (!_n && _i["return"] != null) _i["return"]();
      } finally {
        if (_d) throw _e;
      }
    }return _arr;
  }

  function _arrayWithHoles(arr) {
    if (Array.isArray(arr)) return arr;
  }

  var _default = (0, _reactRouterDom.withRouter)(function (_ref) {
    var children = _ref.children,
        _ref$match$params = _ref.match.params,
        dataDefinitionId = _ref$match$params.dataDefinitionId,
        dataListViewId = _ref$match$params.dataListViewId;

    var _useReducer = (0, _react.useReducer)(_EditTableViewContext.reducer, _EditTableViewContext.initialState),
        _useReducer2 = _slicedToArray(_useReducer, 2),
        state = _useReducer2[0],
        dispatch = _useReducer2[1];

    (0, _react.useEffect)(function () {
      (0, _client.getItem)("/o/data-engine/v2.0/data-definitions/data-definition-fields/field-types").then(function (fieldTypes) {
        dispatch({
          payload: {
            fieldTypes: fieldTypes
          },
          type: _EditTableViewContext.UPDATE_FIELD_TYPES
        });
      });
    }, []);
    (0, _react.useEffect)(function () {
      (0, _client.getItem)("/o/data-engine/v2.0/data-definitions/".concat(dataDefinitionId)).then(function (dataDefinition) {
        dispatch({
          payload: {
            dataDefinition: dataDefinition
          },
          type: _EditTableViewContext.UPDATE_DATA_DEFINITION
        });
      });
    }, [dataDefinitionId]);
    (0, _react.useEffect)(function () {
      if (dataListViewId) {
        (0, _client.getItem)("/o/data-engine/v2.0/data-list-views/".concat(dataListViewId)).then(function (dataListView) {
          dispatch({
            payload: {
              dataListView: dataListView
            },
            type: _EditTableViewContext.UPDATE_DATA_LIST_VIEW
          });
        });
      }
    }, [dataListViewId]);
    return _react["default"].createElement(_EditTableViewContext["default"].Provider, {
      value: [state, dispatch]
    }, children);
  });

  exports["default"] = _default;
  //# sourceMappingURL=EditTableViewContextProvider.es.js.map
});
//# sourceMappingURL=EditTableViewContextProvider.es.js.map
